@@ -1,5 +1,5 @@
-# $Id: Attributes.pm 35477 2011-09-01 11:43:51Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Attributes.pm $
+# $Id: Attributes.pm 35513 2011-09-05 16:16:43Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Attributes.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -14,7 +14,6 @@ use Aselect::Handler -self;
 
 sub handle {
 	my $req = new Aselect::UI::Attributes::Request(cfg => $self, ctx => shift);
-	return unless $req->uid;
 	my $doc = new Aselect::UI::Attributes::Document(req => $req);
 	return $doc->response;
 }
