@@ -1,5 +1,5 @@
-# $Id: Password.pm 35002 2011-06-09 15:13:06Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Password.pm $
+# $Id: Password.pm 35898 2011-11-05 11:53:40Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Password.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -16,7 +16,7 @@ use Aselect::Handler -self;
 sub handle {
 	my $req = new Aselect::UI::Password::Request(cfg => $self, ctx => shift);
 	return if $req->gateway;
-	my $doc = $req->login
+	my $doc = $req->uid
 		? new Aselect::UI::Login::Success(req => $req)
 		: new Aselect::UI::Password::Document(req => $req);
 	return $doc->response;
