@@ -1,5 +1,5 @@
-# $Id: Authenticate.pm 35117 2011-06-27 20:15:11Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/SPNEGO/Authenticate.pm $
+# $Id: Authenticate.pm 35817 2011-10-20 13:08:03Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/SPNEGO/Authenticate.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -7,7 +7,7 @@ use utf8;
 
 package Aselect::UI::SPNEGO::Authenticate;
 
-use Aselect::UI::Document -self;
+use Aselect::UI::Login::Document -self;
 
 sub build {
 	$self->setDocumentElement($self->construct('spnego'));
