@@ -1,5 +1,5 @@
-# $Id: Document.pm 35761 2011-10-12 18:45:02Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Settings/Document.pm $
+# $Id: Document.pm 36052 2011-11-17 18:43:03Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Settings/Document.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -7,8 +7,6 @@ use utf8;
 
 package Aselect::UI::Settings::Document;
 
-use Xyzzy::Util qw(iso8601);
-
 use Aselect::UI::Document -self;
 
 sub build {
@@ -29,6 +27,16 @@ sub response {
 		$res->setcookie($cookie);
 	}
 
+	if((my $remember = $req->new_remember) ne $req->cur_remember) {
+		my $cookie = $self->bakecookie(remember => $remember);
+		if($remember eq 'false') {
+			$cookie->expire('1y');
+		} else {
+			$cookie->expire(0);
+		}
+		$res->setcookie($cookie);
+	}
+
 	if((my $spnego = $req->new_spnego) ne $req->cur_spnego) {
 		my $cookie = $self->bakecookie(spnego => $spnego);
 		if($spnego eq 'auto') {
