@@ -1,5 +1,5 @@
-# $Id: Request.pm 35506 2011-09-05 12:56:55Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Static/Request.pm $
+# $Id: Request.pm 36089 2011-11-23 19:23:06Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Static/Request.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -8,12 +8,14 @@ use utf8;
 package Aselect::UI::Static::Request;
 
 use Xyzzy::Static;
+use Aselect::UI::Error::HTTP;
 
 use Aselect::UI::Request -self;
 use Xyzzy::Static::Request -mixin;
 
 sub error {
-	return super('http', undef, number => shift, url => $self->url, page => $self->path_translated);
+	my $doc = new Aselect::UI::Error::HTTP(req => $self, number => shift);
+	return $doc->response;
 }
 
 sub path_components {
