@@ -1,5 +1,5 @@
-# $Id: Windshield.pm 35587 2011-09-19 13:16:49Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Windshield.pm $
+# $Id: Windshield.pm 35957 2011-11-10 20:23:17Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Windshield.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -13,9 +13,10 @@ sub handle {
 	my $res = eval { super };
 	return $res if $res;
 	my $exc = $@;
-	die $exc if ref $exc;
+	die $exc if UNIVERSAL::isa($exc, 'Xyzzy::Response');
+	warn $exc;
 	my $req = new Aselect::UI::Request(cfg => $self, ctx => shift);
 	$res = $req->error('internal', $exc);
 	$res->status(500);
-	return $res;
+	die $res;
 }
