@@ -1,5 +1,5 @@
-# $Id: Util.pm 30486 2010-03-24 16:59:25Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/Util.pm $
+# $Id: Util.pm 35959 2011-11-11 08:55:53Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/Util.pm $
 
 use utf8;
 use strict;
@@ -13,13 +13,17 @@ use Exporter 'import';
 
 our @EXPORT = qw(aselect_split aselect_join aselect_url aselect_valid aselect_encode aselect_decode);
 
-my $timeout = 10;
+sub uri_unescape_plus {
+	my $str = shift;
+	$str =~ tr/+/ /;
+	return uri_unescape($str);
+}
 
 sub aselect_split {
 	my @items;
 	foreach(split('&', shift)) {
 		my ($key, $val) = split(/=/o, $_, 2);
-		$val = uri_unescape($val) if defined $val;
+		$val = uri_unescape_plus($val) if defined $val;
 		push @items, $key, $val;
 	}
 	return wantarray ? @items : \@items;
@@ -54,6 +58,8 @@ sub aselect_valid {
 
 sub aselect_url {
 	my $url = shift;
+	$url =~ s/(\#.*)//;
+	my $frag = $1 // '';
 	my $sep = index($url, '?') == -1 ? '?' : '&';
 	my @ret = ($url);
 	my $q = $_[0];
@@ -61,10 +67,10 @@ sub aselect_url {
 	while(@_) {
 		my $key = shift;
 		my $val = shift;
-		push @ret, $sep, $key, '=', uri_escape($val);
+		push @ret, $sep, uri_escape($key), '=', uri_escape($val);
 		$sep = '&';
 	}
-	return join('', @ret)
+	return join('', @ret, $frag);
 }
 
 1;
