@@ -1,5 +1,5 @@
-# $Id: Request.pm 35786 2011-10-17 15:25:44Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/WS/Responder/Request.pm $
+# $Id: Request.pm 36053 2011-11-17 19:01:14Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/WS/Responder/Request.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -7,7 +7,7 @@ use utf8;
 
 package Aselect::WS::Responder::Request;
 
-use Aselect::UI::Request -self;
+use Aselect::Request -self;
 
 param request => sub { die "0030 Required request parameter 'request' not supplied\n" unless defined };
 param signature => sub { die "0030 Required request parameter 'signature' not supplied\n" unless defined };
