@@ -1,5 +1,5 @@
-# $Id: Request.pm 34998 2011-06-09 08:37:22Z wsl $
-# $URL: https://infix.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/WS/ValidateCAS/Request.pm $
+# $Id: Request.pm 36053 2011-11-17 19:01:14Z wsl $
+# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/WS/ValidateCAS/Request.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -7,12 +7,11 @@ use utf8;
 
 package Aselect::WS::ValidateCAS::Request;
 
-use Aselect::UI::Request -self;
+use Aselect::Request -self;
 
 param service => sub { die shift->error("Required request parameter 'service' not supplied") unless defined };
 param ticket => sub { die shift->error("Required request parameter 'ticket' not supplied") unless defined };
 param pgtUrl => sub { 'FIXME' };
-param renew => sub { 'FIXME' };
 
 const uid => sub {
 	my $self = shift;
@@ -22,8 +21,17 @@ const uid => sub {
 	my $ticket = $self->ticket;
 	my $service = $self->service;
 
-	my (undef, undef, $uid) = eval { $crypto->check_cas_token('ST', $service, $ticket, $cfg->credential_timeout) };
-	warn "validate: $@" if $@;
+	my (undef, undef, $uid, $renew) = eval { $crypto->check_cas_token('ST', $service, $ticket, $cfg->credential_timeout) };
+	if($@) {
+		warn "validate: $@";
+		return undef;
+	}
+	
+	if($self->renew && !$renew) {
+		warn "CAS validation request requested checking that the supplied ticket (uid=$uid) is renewed but it isn't\n";
+		return undef;
+	}
+
 	return $uid;
 };
 
